package com.rjconsultores.ventaboletos.web.gui.controladores.relatorios;

import java.util.HashMap;
import java.util.Map;

import javax.sql.DataSource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zul.Radio;
import org.zkoss.zul.Textbox;

import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.entidad.PuntoVenta;
import com.rjconsultores.ventaboletos.relatorios.impl.RelatorioMovimentosAtraso;
import com.rjconsultores.ventaboletos.relatorios.utilitarios.Relatorio;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;
import com.rjconsultores.ventaboletos.vo.comissao.MovimentosAtrasoVO.SituacaoDiaMovimento;
import com.rjconsultores.ventaboletos.web.utilerias.MaskUtil;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;

@Scope("prototype")
@Controller("relatorioMovimentosAtrasoController")
public class RelatorioMovimentosAtrasoController extends MyGenericForwardComposer {

	private static final long serialVersionUID = 1L;
	
	private static final Logger log = LoggerFactory.getLogger(RelatorioMovimentosAtrasoController.class);
	
	@Autowired
	private DataSource dataSourceRead;

    private Textbox txtCompetencia;
    private PuntoVenta puntoVenta;
    private Empresa empresa;
    
    private Radio rTodos;
    private Radio rEntregue;
    private Radio rAtrasado;
    private Radio rAguardando;
    
    @Override
    public void doAfterCompose(Component comp) throws Exception {
        super.doAfterCompose(comp);
        aplicarMascara();
        txtCompetencia.focus();
    }
    
    public void onClick$btnRelatorio(Event ev) {
    	try {
    		Map<String, Object> parametros = new HashMap<String, Object>();
        	parametros.put("competencia", txtCompetencia.getValue());
        	parametros.put("empresaId", empresa.getEmpresaId());
        	parametros.put("empresa", empresa.getNombempresa());
        	parametros.put("usuario", UsuarioLogado.getUsuarioLogado().getNombmaterno());
        	parametros.put("situacaoEntregue", SituacaoDiaMovimento.ENTREGUE.toString());
        	parametros.put("shortSituacaoEntregue", SituacaoDiaMovimento.ENTREGUE.getShortDescricao());
        	parametros.put("situacaoAtrasado", SituacaoDiaMovimento.ATRASADO.toString());
        	parametros.put("shortSituacaoAtrasado", SituacaoDiaMovimento.ATRASADO.getShortDescricao());
        	parametros.put("situacaoAguardando", SituacaoDiaMovimento.AGUARDANDO.toString());
        	parametros.put("shortSituacaoAguardando", SituacaoDiaMovimento.AGUARDANDO.getShortDescricao());
        	
        	if(rEntregue.isChecked()) {
        		parametros.put("status", SituacaoDiaMovimento.ENTREGUE);
        	} else if(rAtrasado.isChecked()) {
        		parametros.put("status", SituacaoDiaMovimento.ATRASADO);
        	} else if(rAguardando.isChecked()) {
        		parametros.put("status", SituacaoDiaMovimento.AGUARDANDO);
        	}

        	if(puntoVenta != null) {
        		parametros.put("puntoventaId", puntoVenta.getPuntoventaId());
        		parametros.put("puntoventa", puntoVenta.getNombpuntoventa());
        	} else {
        		parametros.put("puntoventa", "Todos");
        	}
        	
    		Relatorio relatorio =  new RelatorioMovimentosAtraso(parametros, dataSourceRead.getConnection());
        	
        	Map<String, Object> args = new HashMap<String, Object>();
    		args.put("relatorio", relatorio);

    		openWindow("/component/reportView.zul",
    				   Labels.getLabel("relatorioMovimentosAtrasoController.window.title"), args, MODAL);			
		} catch (Exception e) {
			log.error(e.getMessage(), e);
		}
    }

	public PuntoVenta getPuntoVenta() {
		return puntoVenta;
	}

	public void setPuntoVenta(PuntoVenta puntoVenta) {
		this.puntoVenta = puntoVenta;
	}

	public Empresa getEmpresa() {
		return empresa;
	}

	public void setEmpresa(Empresa empresa) {
		this.empresa = empresa;
	}
	
	public void aplicarMascara() {
		MaskUtil.aplicarMascara(txtCompetencia.getUuid(), "99/9999");
	}

}
