package com.rjconsultores.ventaboletos.web.gui.controladores.relatorios;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.sql.DataSource;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zul.Comboitem;

import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.entidad.Ruta;
import com.rjconsultores.ventaboletos.entidad.VigenciaTarifa;
import com.rjconsultores.ventaboletos.relatorios.impl.RelatorioTabelaPreco;
import com.rjconsultores.ventaboletos.relatorios.utilitarios.Relatorio;
import com.rjconsultores.ventaboletos.service.EmpresaService;
import com.rjconsultores.ventaboletos.service.RutaService;
import com.rjconsultores.ventaboletos.service.VigenciaTarifaService;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxEstandar;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;

@Controller("relatorioTabelaPrecoController")
@Scope("prototype")
public class RelatorioTabelaPrecoController extends MyGenericForwardComposer {

	private static final long serialVersionUID = 1L;

	private MyComboboxEstandar cmbVigencia;
	private List<VigenciaTarifa> lsVigencia;
	private MyComboboxEstandar cmbEmpresa;
	private List<Empresa> lsEmpresa;
	private MyComboboxEstandar cmbRuta;
	private List<Ruta> lsRuta;

	@Autowired
	private VigenciaTarifaService vigenciaTarifaService;
	@Autowired
	private EmpresaService empresaService;
	@Autowired
	private RutaService rutaService;
	@Autowired
	private DataSource dataSourceRead;	
	
	@Override
	public void doAfterCompose(Component comp) throws Exception {
		lsVigencia = vigenciaTarifaService.obtenerTodos();
		lsEmpresa = empresaService.obtenerTodos();
		lsRuta = rutaService.obtenerTodos();
		super.doAfterCompose(comp);	
	}

	/**
	 * @throws Exception
	 * 
	 */
	@SuppressWarnings({ "rawtypes", "unchecked" })
	private void executarRelatorio() throws Exception {
		{
				Relatorio relatorio;
	
				Map<String, Object> parametros = new HashMap<String, Object>();
		
				parametros.put("NOME_RELATORIO", Labels.getLabel("relatorioTabelaPrecoController.window.title"));
				parametros.put("USUARIO", UsuarioLogado.getUsuarioLogado().getUsuarioId().toString());
				parametros.put("USUARIO_NOME", UsuarioLogado.getUsuarioLogado().getNombusuario());
				
				Comboitem itemVigencia = cmbVigencia.getSelectedItem();
				if(itemVigencia != null){
					VigenciaTarifa vigencia = (VigenciaTarifa) itemVigencia.getValue();
					parametros.put("VIGENCIA_ID", vigencia.getVigenciatarifaId());
					parametros.put("VIGENCIA_INICIAL", vigencia.getFeciniciovigencia());
					parametros.put("VIGENCIA_FINAL", vigencia.getFecfinvigencia());
				}
				
				Comboitem itemEmpresa = cmbEmpresa.getSelectedItem();
				if (itemEmpresa != null) {
					Empresa empresa = (Empresa) itemEmpresa.getValue();
					parametros.put("EMPRESA_ID", empresa.getEmpresaId());
					parametros.put("EMPRESA", empresa.getNombempresa());
				}
				
				Comboitem itemRuta = cmbRuta.getSelectedItem();
				if (itemRuta != null) {
					Ruta ruta = (Ruta) itemRuta.getValue();
					parametros.put("RUTA_ID", ruta.getRutaId());
					parametros.put("RUTA", ruta.getDescruta());
				}
			
				relatorio = new RelatorioTabelaPreco(parametros, dataSourceRead.getConnection());
				
				Map args = new HashMap();
				args.put("relatorio", relatorio);
	
				openWindow("/component/reportView.zul",
						Labels.getLabel("relatorioTabelaPrecoController.window.title"), args, MODAL);
		   }
		
	}

	public void onClick$btnExecutarRelatorio(Event ev) throws Exception{
		executarRelatorio();
	}
	

	public List<Empresa> getLsEmpresa() {
		return lsEmpresa;
	}

	public void setLsEmpresa(List<Empresa> lsEmpresa) {
		this.lsEmpresa = lsEmpresa;
	}

	public MyComboboxEstandar getCmbEmpresa() {
		return cmbEmpresa;
	}

	public void setCmbEmpresa(MyComboboxEstandar cmbEmpresa) {
		this.cmbEmpresa = cmbEmpresa;
	}

	public MyComboboxEstandar getCmbRuta() {
		return cmbRuta;
	}

	public void setCmbRuta(MyComboboxEstandar cmbRuta) {
		this.cmbRuta = cmbRuta;
	}

	public List<Ruta> getLsRuta() {
		return lsRuta;
	}

	public void setLsRuta(List<Ruta> lsRuta) {
		this.lsRuta = lsRuta;
	}

	public MyComboboxEstandar getCmbVigencia() {
		return cmbVigencia;
	}

	public void setCmbVigencia(MyComboboxEstandar cmbVigencia) {
		this.cmbVigencia = cmbVigencia;
	}

	public List<VigenciaTarifa> getLsVigencia() {
		return lsVigencia;
	}

	public void setLsVigencia(List<VigenciaTarifa> lsVigencia) {
		this.lsVigencia = lsVigencia;
	}	
	
	
	
}
